aboutsummaryrefslogtreecommitdiffstats
path: root/wiretap/etherpeek.c
diff options
context:
space:
mode:
authorguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2002-01-29 09:45:58 +0000
committerguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2002-01-29 09:45:58 +0000
commit87859a653d416075359509af21692f78d896ddfa (patch)
treeaee45c0a61eaedb10e87afe5ffa3f90d2f08d731 /wiretap/etherpeek.c
parent0be04089580b08e9e65fb8bc0f1104a223c75556 (diff)
Untested support for AiroPeek captures.
git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@4619 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'wiretap/etherpeek.c')
-rw-r--r--wiretap/etherpeek.c11
1 files changed, 4 insertions, 7 deletions
diff --git a/wiretap/etherpeek.c b/wiretap/etherpeek.c
index 8a9c134994..6844e26e3a 100644
--- a/wiretap/etherpeek.c
+++ b/wiretap/etherpeek.c
@@ -2,7 +2,7 @@
* Routines for opening EtherPeek (and TokenPeek?) files
* Copyright (c) 2001, Daniel Thompson <d.thompson@gmx.net>
*
- * $Id: etherpeek.c,v 1.13 2002/01/23 06:32:51 guy Exp $
+ * $Id: etherpeek.c,v 1.14 2002/01/29 09:45:58 guy Exp $
*
* Wiretap Library
* Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -225,12 +225,9 @@ int etherpeek_open(wtap *wth, int *err)
* 802.11, with a private header giving
* some radio information. Presumably
* this is from AiroPeek.
- *
- * We don't yet support that.
*/
- g_message("etherpeek: 802.11 captures unsupported");
- *err = WTAP_ERR_UNSUPPORTED_ENCAP;
- return -1;
+ file_encap = WTAP_ENCAP_AIROPEEK;
+ break;
default:
/*
@@ -283,7 +280,7 @@ int etherpeek_open(wtap *wth, int *err)
}
/*
* This is an EtherPeek (or TokenPeek?) file.
*
* At this point we have recognised the file type and have populated
* the whole ep_hdr structure in host byte order.
@@ -283,7 +280,7 @@ int etherpeek_open(wtap *wth, int *err)
}
/*
- * This is an EtherPeek (or TokenPeek?) file.
+ * This is an EtherPeek (or TokenPeek or AiroPeek?) file.
*
* At this point we have recognised the file type and have populated